# lite-merge
<div>
    <a href="https://www.npmjs.com/package/lite-merge"><img src="https://img.shields.io/npm/v/lite-merge.svg" alt="NPM version" /></a>
    <a href="https://www.npmjs.com/package/lite-merge"><img src="https://img.shields.io/npm/dt/lite-merge.svg" alt="NPM downloads" /></a>
    <a href="https://www.patreon.com/fataussie"><img src="https://img.shields.io/badge/donate-patreon-F96854" alt="Patreon" /></a>
</div>

A lightweight deep merging object handler, useful if you need to combine an object or group of objects into one single object overwriting/creating keys and values.

## Getting Started
Install the **npm package**
```
npm install lite-merge
```
Require it into your code.
```js
var merge = require('lite-merge');
```
Merge objects
```js
let object = { facts: { strawberry_is_berry: false } },
    target = { facts: { banana_is_berry: true } };

merge(object, target); // { facts: { strawberry_is_berry: false, banana_is_berry: true } }
```

## Merge Function
The merge function is the default module export of the package, below I have detailed some use cases of the function.

| param   | type                    | optional | description |
| :------ | :---------------------- | :------- | :---------- |
| object  | Object\|Array\<Object\> | false    | The object(s) to merge into the target
| target  | Object                  | false    | The targeted object being merged into
| options | MergeOptions            | true     | The options to parse while merging

## Merge Options
You can add an extra level of customization to your merging by using the `Merge Options`

| option    | type      | default | description |
| :-------- | :-------- | :------ | :---------- |
| sort      | *boolean* | false   | Organise combined arrays in alphabetic and numeric order
| overwrite | *boolean* | true    | Overwrite the values of any keys that already exist
| depth     | *number*  | -1      | The number of steps down the object tree before stopping deep merge

## Basic Merge
This will be the most common use of the function, this merges two objects together setting/overwriting object values.
>This will also sort any arrays contained in the objects in alphabetic and numeric form.

```js
let object = { letters: ['d', 'e', 'f'], numbers: { 4: 'four', 5: 'five', 6: 'six' }, settings: { favourite: 'e' } },
    target = { letters: ['a', 'b', 'c'], numbers: { 1: 'one', 2: 'two', 3: 'three' } };

merge(object, target);
```

If you were to console log the merge function you'd be presented with something like this.

```
{ 
    stuff: { 
        letters: [ 'a', 'b', 'c', 'd', 'e', 'f' ], 
        numbers: { 
            '1': 'one',
            '2': 'two',
            '3': 'three',
            '4': 'four',
            '5': 'five',
            '6': 'six'
        } 
    },
    settings: { 
        favourite: 'e' 
    }
}
```

This is the newly modified `target` object, 
* The letters array has been combined and sorted in alphabetic order,
* The numbers objects have been combined,
* and the settings object has been added.

## Multiple Object Merging
The merge function lets you merge multiple objects into another without needing to call it for each object individually.

To do this just put the objects you desire to merge into an array as the first parameter.
```js
merge([object, target], {})
```